# tests/test_chronos.py
import unittest
# from .aion_xtensions_chronos.mapper.chronos_mapper import ChronosMappingBuilder
from ..aion_xtensions_chronos.mapper.chronos_mapper import ChronosMappingBuilder
class TestAionXtensionsChronos(unittest.TestCase):

    def test_generate_mappings(self):
        data = {
            "incident": {
                "group_prediction": ["group_prediction", "agent_prediction", "exp_resolution_time", "fcr", "re_open", "dsat"]
            }
        }
        ax_mapper = ChronosMappingBuilder(data)
        result = ax_mapper.generate_mappings()
        self.assertEqual(result["status"], "success")
        self.assertEqual(len(result["data"]), 1)  # Check if one module is processed
        self.assertIn("AX1", result["data"][0]["incident"]["group_prediction"])

if __name__ == '__main__':
    unittest.main()



# setup.py

from setuptools import setup, find_packages

setup(
    name='aion_chronos',  # Package name (use hyphens for PyPI)
    version='0.1',
    description='Aion Xtensions Chronos to generate AX mappings based on modules and use cases.',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author='Aion',
    author_email='aion@hcl.com',
    url='https://github.com/yourusername/aion-xtensions-chronos',  # Update with your actual URL
    packages=find_packages(),
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    install_requires=[],  # Add any dependencies here
    python_requires='>=3.6',
)
